# CHANGELOG


## v0.3.1 (2025-05-09)

### Bug Fixes

- Fix the message example
  ([`e14b854`](https://github.com/keying-one/mixin-client-private/commit/e14b85441f52ca4e373483541e9b29ca5acc0dfc))


## v0.3.0 (2025-05-09)

### Features

- Support sending PLAIN_TEXT messages with base64 encoded data, refactor API interface, and clean up
  debug prints
  ([`f617073`](https://github.com/keying-one/mixin-client-private/commit/f617073799f76ee587f4bd6321823f47555924da))

### Refactoring

- Use RequestTimeoutError and RequestError
  ([`5c80b13`](https://github.com/keying-one/mixin-client-private/commit/5c80b1308ab9a4423315d6b2afa1889f8b45392b))


## v0.2.0 (2025-05-09)

### Bug Fixes

- Change to static version number 0.3.3
  ([`0d7ebbc`](https://github.com/keying-one/mixin-client-private/commit/0d7ebbcef7f961e4fecac2cf9d9ab887e1ec78bc))

- Change to static version number 0.3.3
  ([`03c8139`](https://github.com/keying-one/mixin-client-private/commit/03c8139511d5ec5d541d51745bb0c74410c4c5ee))

- Clean release github actions
  ([`d21075d`](https://github.com/keying-one/mixin-client-private/commit/d21075d91dd480780f95211bffada9d2ed40b0fc))

- Fix release workflow
  ([`6deb517`](https://github.com/keying-one/mixin-client-private/commit/6deb517aa122f08595984352de1169e670ee112f))

- Fix release workflow
  ([`ac92cb0`](https://github.com/keying-one/mixin-client-private/commit/ac92cb0c4196f6e5d87560f433d09b4706166547))

- Fix semantic-release workflow with setuptools_scm
  ([`1a1a692`](https://github.com/keying-one/mixin-client-private/commit/1a1a6927bb32247844ce956f7ab03d7b1348a1c8))

- Pypi is ok, but fix github release workflow
  ([`aca565c`](https://github.com/keying-one/mixin-client-private/commit/aca565c0459881295eae291b1d5a4742a431e60c))

- Show version
  ([`fef0d48`](https://github.com/keying-one/mixin-client-private/commit/fef0d48aa5a78aed3ee6c5e0143b821fb5fea73e))

### Chores

- Format code with ruff
  ([`ef52fea`](https://github.com/keying-one/mixin-client-private/commit/ef52fea9b615d820d57e75408c74660af2d2ea85))

- 重置版本号回 0.1.0
  ([`df8d935`](https://github.com/keying-one/mixin-client-private/commit/df8d9358dcd955a03830d8aa5ef8ef5f78c99b34))

### Documentation

- Add changelog
  ([`db3e449`](https://github.com/keying-one/mixin-client-private/commit/db3e449ad91b07f28bfc79b1d77aee708f4166c7))

### Features

- Downgrade semantic-release to 8.1.1
  ([`ecf9ed2`](https://github.com/keying-one/mixin-client-private/commit/ecf9ed2bb037ff0256744e389f722431ae47116c))

- Fix for github action test
  ([`8c026af`](https://github.com/keying-one/mixin-client-private/commit/8c026af422bebed1d85b0df87a7ad5d82dfcffe9))

- Python-semantic-release with pypa/gh-action-pypi-publish@release/v1
  ([`47062fc`](https://github.com/keying-one/mixin-client-private/commit/47062fca08131c1a90bae114b7be417720dcfe06))

- Remove publish workflow
  ([`1c47590`](https://github.com/keying-one/mixin-client-private/commit/1c47590ec12cb9c8628b2e53ed004d74be31c9d1))

- Test
  ([`cca7573`](https://github.com/keying-one/mixin-client-private/commit/cca7573064b5d7e304650c1edff1425e2caa283f))

- Test new feature for semantic release
  ([`d0efba7`](https://github.com/keying-one/mixin-client-private/commit/d0efba7ed6e82df1ec5f5a450073da1a35f82b67))

- Test pypi publish on github actions
  ([`d60ecef`](https://github.com/keying-one/mixin-client-private/commit/d60ecefacce5223b12baf00b2d6cf640e635b371))

- Test semantic release
  ([`4aa2cf3`](https://github.com/keying-one/mixin-client-private/commit/4aa2cf3809aca4ed4f983fbcfbfadb929a0348cf))

- Test semantic release
  ([`17a1702`](https://github.com/keying-one/mixin-client-private/commit/17a17027785e9bed931d4ee4e173e37d3c6b0b87))

- Test semantic release again
  ([`f4f87a8`](https://github.com/keying-one/mixin-client-private/commit/f4f87a8d02344f3b0e5365b493abe7ef13099310))

- Test semantic release more and more
  ([`a80ab29`](https://github.com/keying-one/mixin-client-private/commit/a80ab293a9707c9f9ed7bd6105b45eea590ea6a7))

- Test semantic-release workflow
  ([`c65bf70`](https://github.com/keying-one/mixin-client-private/commit/c65bf70d70c5e218f706e9e2fbb0868cff61d158))

- Test semantic-release workflow
  ([`9def492`](https://github.com/keying-one/mixin-client-private/commit/9def492c3e0def7baf08c13f3d5ce943d2db152b))

- Update version to 0.2.0
  ([`72a6b4b`](https://github.com/keying-one/mixin-client-private/commit/72a6b4b65dda929f78ec0556ceaef3c7a689bee9))

- Use semantic-release without env variables
  ([`c880615`](https://github.com/keying-one/mixin-client-private/commit/c88061538b2a7328acdd3d6111881a4687dbef84))


## v0.1.0 (2025-05-08)

### Chores

- Bump version to 0.0.2
  ([`93619da`](https://github.com/keying-one/mixin-client-private/commit/93619da14a472b1eddd067337dc2ae1ac37eaa3f))

- Bump version to 0.0.3
  ([`e475ba9`](https://github.com/keying-one/mixin-client-private/commit/e475ba9a2604cb671f36dbc85b001e0d6a013162))

### Features

- Fix for github action test
  ([`c3c8754`](https://github.com/keying-one/mixin-client-private/commit/c3c8754d16405180f094f6eabd61c90809d0d53f))

- Test python semantic release
  ([`670f59b`](https://github.com/keying-one/mixin-client-private/commit/670f59bd454d75e657c392d70f4de06f03cabf46))

- Test the pypi release github action support
  ([`d069e5f`](https://github.com/keying-one/mixin-client-private/commit/d069e5f49e0196aeb3143b4c6ec9e07ab508e6f2))
